@@ -4,13 +4,13 @@
  * This file is part of ePiX, a C++ library for creating high-quality 
  * figures in LaTeX 
  *
- * Version 1.1.10
- * Last Change: August 04, 2007
+ * Version 1.2.17
+ * Last Change: July 20, 2017
  */
 
 /* 
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007
- * Andrew D. Hwang <rot 13 nujnat at zngupf dot ubylpebff dot rqh>
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2017
+ * Andrew D. Hwang <ahwang -at- holycross -dot- edu>
  * Department of Mathematics and Computer Science
  * College of the Holy Cross
  * Worcester, MA, 01610-2395, USA
@@ -52,10 +52,12 @@
 
 namespace ePiX {
 
+  class Complex;
   class P {
   public:
     P(double arg1=0, double arg2=0, double arg3=0);
-
+    P(const Complex&);
+    
     double x1() const;
     double x2() const;
     double x3() const;
